@@ -3,7 +3,7 @@ use strict;
 use warnings;
 use base qw/Net::CIDR::MobileJP::Scraper::Plugin/;
 
-sub url { return 'http://www.nttdocomo.co.jp/service/imode/make/content/ip/about/'; }
+sub url { return 'http://www.nttdocomo.co.jp/service/imode/make/content/ip/'; }
 
 sub run {
     my ($self, ) = @_;
@@ -11,7 +11,7 @@ sub run {
     my $url = $self->url;
     my $content = $self->get($url);
     my @result;
-    while ($content =~ m!<FONT COLOR="\#009900"><B>(.*?)</B></FONT>!g) {
+    while ($content =~ m!<li>([\d\.\/]+)</li>!g) {
         push @result, $1;
     }
     return \@result;
